﻿using Microsoft.EntityFrameworkCore;
using MusicManager.Model;
using System;
using System.Collections.Generic;
using System.Text;

namespace MusicManager.DBContext
{
    public class SongContext : DbContext
    {
        //Entity
        public DbSet<Song> Songs { get; set; }
        public DbSet<Genre> Genres { get; set; }
        public DbSet<OrderList> OrderLists { get; set; }
        public DbSet<Status> Statuses { get; set; }
        public DbSet<User> Users { get; set; }

        protected override void OnConfiguring(DbContextOptionsBuilder optionsBuilder)
        {
            optionsBuilder.UseMySql("CONNECTIONSTRING");
        }

        protected override void OnModelCreating(ModelBuilder modelBuilder)
        {
            // Song (n) - Genre (1)
            modelBuilder.Entity<Song>()
                .HasOne(s => s.Genre)
                .WithMany(g => g.Songs)
                .HasForeignKey(s => s.GenreID);

            //Song (n) - List (1)
            modelBuilder.Entity<Song>()
                .HasOne(s => s.OrderList)
                .WithMany(l => l.Songs)
                .HasForeignKey(s => s.OrderListID);

            //List (n) - Status (1)
            modelBuilder.Entity<OrderList>()
                .HasOne(l => l.Status)
                .WithMany(s => s.OrderLists)
                .HasForeignKey(l => l.StatusID);
        }
    }
}
