﻿using System.Collections.Generic;
using System.Linq;
using System.Windows;
using System.Windows.Input;

namespace MusicManager.View
{
    /// <summary>
    /// Interaktionslogik für PWindow.xaml
    /// </summary>
    public partial class PWindow : Window
    {
        public object MContext;

        public bool CanCloseWithEsc
        {
            get
            {
                return System.Convert.ToBoolean(GetValue(CanCloseWithEscProperty));
            }

            set
            {
                SetValue(CanCloseWithEscProperty, value);
            }
        }


        public static readonly DependencyProperty CanCloseWithEscProperty = DependencyProperty.Register("CanCloseWithEsc", typeof(bool), typeof(PWindow), new PropertyMetadata(true));



        public bool AsPModalDialog
        {
            get
            {
                return System.Convert.ToBoolean(GetValue(AsPModalDialogProperty));
            }

            set
            {
                SetValue(AsPModalDialogProperty, value);
            }
        }

        public static readonly DependencyProperty AsPModalDialogProperty = DependencyProperty.Register("AsPModalDialog", typeof(bool), typeof(PWindow), new PropertyMetadata(true));


        public PWindow(string name)
        {
            this.Name = name;
            InitializeComponent();
        }

        public PWindow(string name, object datacontext, SizeToContent sizeToContent = SizeToContent.WidthAndHeight, WindowStartupLocation startPosition = WindowStartupLocation.CenterScreen)
        {
            this.Name = name;
            MContext = datacontext;

            this.SizeToContent = sizeToContent;
            WindowStartupLocation = startPosition;
            InitializeComponent();
        }

        private void PWindow_Loaded(object sender, RoutedEventArgs e)
        {
            PreviewKeyDown += Window_KeyDown;

            if (AsPModalDialog)
            {
                if (Owner != null)
                    ShowInTaskbar = false;
            }

            DataContext = MContext;
            BringIntoView();
        }

        private void Window_KeyDown(object sender, KeyEventArgs e)
        {
            if (e.Key == Key.Escape && CanCloseWithEsc)
                Close();
        }


        public Window FindOwnerWindow(object viewModel)
        {
            // if the ViewModel of the caller is set, we try to find the corresponding Window
            if (viewModel != null)
            {
                if (viewModel.GetType() == typeof(PWindow))
                    return (Window)viewModel;

                if (Application.Current.Windows.Cast<Window>().SingleOrDefault(x => x.DataContext != null && x.DataContext.GetType() == viewModel.GetType()) == null)
                {
                    IEnumerable<Window> allWindows = from win in Application.Current.Windows.Cast<Window>().ToList() select win;
                    foreach (Window window in allWindows)
                    {
                        if (window.DataContext != null && window.DataContext.GetType() == viewModel.GetType())
                        {
                            return window;
                        }
                    }
                }
                else
                {
                    return Application.Current.Windows.Cast<Window>().SingleOrDefault(x => x.DataContext != null && x.DataContext.GetType() == viewModel.GetType());
                }
            }
            // by default we use the active Window in the List as owner
            return Application.Current.Windows.Cast<Window>().SingleOrDefault(x => x.IsActive);
        }


        public void SetwinState(bool maximize)
        {
            if (maximize)
                WindowState = WindowState.Maximized;
            else
                WindowState = WindowState.Normal;
        }
    }
}
