﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;

namespace MusicManager.ViewModel.Services
{

    public class ServiceContainer
    {
        public static readonly ServiceContainer Instance = new ServiceContainer();

        static ServiceContainer()
        {
            ServiceMap = new Dictionary<Type, object>();
            ServiceMapLock = new object();
        }

        public void AddService<TServiceContract>(TServiceContract implementation) where TServiceContract : class
        {
            lock (ServiceMapLock)
                ServiceMap[typeof(TServiceContract)] = implementation;
        }

        public static TServiceContract GetService<TServiceContract>() where TServiceContract : class
        {
            object service = null;
            lock (ServiceMapLock)
                ServiceMap.TryGetValue(typeof(TServiceContract), out service);
            return service as TServiceContract;
        }

        private static readonly Dictionary<Type, object> ServiceMap;
        private static readonly object ServiceMapLock;
    }

}
